@@ -1,6 +1,8 @@
+pub mod geometry;
 pub mod material;
 pub mod math;
 pub mod renderer;
 pub mod scene;
+pub mod texture;
 pub mod utils;
 pub mod web;
