@@ -1,16 +1,15 @@
 use std::fs::File;
 
-use crate::scene::texture::{
+use crate::texture::texture::{
 	Texture,
 	TextureFormat,
-	TextureManager,
 };
 
 pub struct TextureLoader {
 }
 
 impl TextureLoader {
-	pub fn load_png(manager: &mut TextureManager, file_path: &str) -> Texture {
+	pub fn load_png(file_path: &str) -> Texture {
 		let decoder = png::Decoder::new(File::open(file_path).unwrap());
 		let mut reader = decoder.read_info().unwrap();
 		let (width, height) = {
@@ -20,7 +19,7 @@ impl TextureLoader {
 		let mut buf = vec![0; reader.output_buffer_size()];
 		reader.next_frame(&mut buf).unwrap();
 
-		manager.create(
+		Texture::new(
 			width,
 			height,
 			TextureFormat::Uint8,
